package com.laguerre.kan;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.opengl.GLES20;
import android.opengl.GLUtils;

public final class Texture2D extends Texture {
	private Bitmap bitmap;

	public void setBitmap(Context context, int resourceId, Bitmap.Config config) {
		setBitmap(context, resourceId, config, true);
	}

	public void setBitmap(Context context, int resourceId, Bitmap.Config config, boolean doFlip) {
		final BitmapFactory.Options options = new BitmapFactory.Options();
		options.inScaled = false;   // No pre-scaling
		options.inPreferredConfig = config;

		// Read in the resource
		this.bitmap = BitmapFactory.decodeResource(
				context.getResources(), resourceId, options);
		if (doFlip) {
			this.bitmap = flipUpsideDown(this.bitmap);
		}
	}

	public static Bitmap flipUpsideDown(Bitmap src) {
		final int width = src.getWidth();
		final int height = src.getHeight();
		final int[] srcContent = new int[height * width];
		final int[] dstContent = new int[height * width];

		src.getPixels(srcContent, 0, width, 0, 0, width, height);
		for (int i = 0; i < height; i++) {
			System.arraycopy(
					srcContent, i * width,
					dstContent, (height - i - 1) * width, width);
		}

		final Bitmap.Config config = src.getConfig();
		return Bitmap.createBitmap(dstContent, width, height, config);
	}

	@Override
	public int getWidth() {
		return this.bitmap.getWidth();
	}

	@Override
	public int getHeight() {
		return this.bitmap.getHeight();
	}

	@Override
	public void create() {
		doCreation();
		// Load the bitmap into the bound texture.
		GLUtils.texImage2D(GLES20.GL_TEXTURE_2D, 0, this.bitmap, 0);
		// Recycle the bitmap, since its data has been loaded into OpenGL.
		bitmap.recycle();
	}
}
