package com.laguerre.kan;

public final class Time {
	private static Time instance = null;
	public static Time getInstance() {
		if (instance == null) {
			instance = new Time();
		}
		return instance;
	}

	private int frameRenderedCount = 0;
	private long timeFrameStarted = 0L;
	private float lastFrameTime = 0f;

	void incrFrameCount() {
		this.frameRenderedCount++;
	}

	void resetTimeFrameStarted() {
		this.timeFrameStarted = System.currentTimeMillis();
	}

	void captureFrameElapsedTime() {
		this.lastFrameTime = getTimeFrameStarted();
	}

	/**
	 * Gets the number of frames that have been rendered since the beginning.
	 * @return the number of frames.
	 */
	public int frameCount() {
		return this.frameRenderedCount;
	}

	/**
	 * Gets the number of seconds elapsed since the frame started.
	 * @return the time elapsed.
	 */
	public float getTimeFrameStarted() {
		return (System.currentTimeMillis() - this.timeFrameStarted) / 1000f;
	}

	/**
	 * Gets the number of seconds elapsed to complete the previous rendered frame:
	 * from update of every {@link SceneObject}, culling, etc. until the last
	 * post-effect of the screen quad.
	 * @return the time elapsed to render the previous frame.
	 */
	public float getLastFrameTime() {
		return this.lastFrameTime;
	}
}
